"use strict";(self.webpackChunk_dagster_io_dagit_app=self.webpackChunk_dagster_io_dagit_app||[]).push([[594],{86594:function(e,t,r){r.r(t),r.d(t,{FallthroughRoot:function(){return g}});var n=r(32030),o=r(34595),i=r(7838),s=r(89646),a=r(75453),c=r(325),l=r(27601),u=r(39061),p=r(76336),d=r(25582),x=r(81745),h=r(32289),f=function(){var e=(0,l.TH)(),t="".concat(e.pathname).concat(e.search);return(0,h.jsx)(l.l_,{to:"/instance".concat(t)})},g=function(){return(0,h.jsxs)(l.rs,{children:[(0,h.jsx)(l.AW,{path:["/runs/(.*)?","/assets/(.*)?","/scheduler"],children:(0,h.jsx)(f,{})}),(0,h.jsx)(l.AW,{path:"/home",children:(0,h.jsx)(m,{})}),(0,h.jsx)(l.AW,{path:"*",children:(0,h.jsx)(m,{})})]})},j=function(e){return e.repository.pipelines.filter((function(e){return!(0,u.pv)(e.name)}))},m=function(){var e=c.useContext(p.C5),t=e.allRepos,r=e.loading,u=e.locationEntries,f=(0,x.gV)().flagNewWorkspace;if(r)return(0,h.jsx)(n.x,{flex:{direction:"row",justifyContent:"center"},style:{paddingTop:"100px"},children:(0,h.jsxs)(n.x,{flex:{direction:"row",alignItems:"center",gap:16},children:[(0,h.jsx)(o.$,{purpose:"section"}),(0,h.jsx)("div",{style:{color:i.w.Gray600},children:"Loading workspace\u2026"})]})});if(u.length&&0===t.length)return(0,h.jsx)(l.l_,{to:"/workspace"});var g=t.filter((function(e){return j(e).length>0}));if(0===g.length){var m=t.find((function(e){return e.repository.assetGroups.length}));if(m)return(0,h.jsx)(l.l_,{to:(0,d.rO)(m.repository.name,m.repositoryLocation.name,"/asset-groups/".concat(m.repository.assetGroups[0].groupName))})}if(1===g.length&&1===j(g[0]).length){var y=g[0],w=j(y)[0];return(0,h.jsx)(l.l_,{to:(0,d.jT)({repoName:y.repository.name,repoLocation:y.repositoryLocation.name,pipelineName:w.name,isJob:w.isJob})})}if(g.length>0)return(0,h.jsx)(l.l_,{to:f?"/instance/runs/timeline":"/instance"});var v=t[0];return(0,h.jsx)(n.x,{padding:{vertical:64},children:(0,h.jsx)(s.t,{icon:"no-results",title:v?"No jobs":"No repositories",description:v?"Your repository is loaded, but no jobs were found.":"Add a repository to get started.",action:(0,h.jsx)(a.fr,{href:"https://docs.dagster.io/getting-started",children:"View documentation"})})})};t.default=g},89646:function(e,t,r){r.d(t,{t:function(){return l}});r(325);var n=r(32030),o=r(7838),i=r(89279),s=r(34595),a=r(12745),c=r(32289),l=function(e){var t=e.title,r=e.description,l=e.icon,u=e.action,p=e.shrinkable,d=1===[t,r,u].filter(Boolean).length;return(0,c.jsxs)(n.x,{flex:{gap:20,alignItems:d?"center":"flex-start"},background:o.w.Gray50,padding:24,style:{margin:"auto",borderRadius:8,width:p?"initial":"max-content",maxWidth:500},children:["spinner"===l?(0,c.jsx)(s.$,{purpose:"section"}):"no-results"===l?(0,c.jsx)(i.JO,{name:"search",size:48,color:o.w.Gray400}):(0,c.jsx)(i.JO,{name:l,size:48,color:o.w.Gray400}),(0,c.jsxs)(n.x,{flex:{gap:8,direction:"column",alignItems:"flex-start"},children:[t&&(0,c.jsx)(a.pm,{style:{color:o.w.Gray900},children:t}),r&&(0,c.jsx)("div",{style:{color:o.w.Gray500},children:r}),u]})]})}}}]);
//# sourceMappingURL=594.c8ca3b2d.chunk.js.map